==> devops-client-java-1.0.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1ProjectManagementProjectInfoFluentImpl.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1alpha1ProjectManagementProjectInfoFluentImpl<A extends V1alpha1ProjectManagementProjectInfoFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1ProjectManagementProjectInfoFluent<A>{

    private String id;
    private String name;

    public V1alpha1ProjectManagementProjectInfoFluentImpl(){
    }
    public V1alpha1ProjectManagementProjectInfoFluentImpl(V1alpha1ProjectManagementProjectInfo instance){
            this.withId(instance.getId());

            this.withName(instance.getName());

    }

    public String getId(){
            return this.id;
    }

    public A withId(String id){
            this.id=id; return (A) this;
    }

    public Boolean hasId(){
            return this.id != null;
    }

    public A withNewId(String arg1){
            return (A)withId(new String(arg1));
    }

    public A withNewId(StringBuilder arg1){
            return (A)withId(new String(arg1));
    }

    public A withNewId(StringBuffer arg1){
            return (A)withId(new String(arg1));
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1ProjectManagementProjectInfoFluentImpl that = (V1alpha1ProjectManagementProjectInfoFluentImpl) o;
            if (id != null ? !id.equals(that.id) :that.id != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            return true;
    }




}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1ProjectManagementProjectInfoFluentImpl.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1alpha1ProjectManagementProjectInfoFluentImpl<A extends V1alpha1ProjectManagementProjectInfoFluent<A>> extends io.alauda.devops.java.client.fluent.BaseFluent<A> implements V1alpha1ProjectManagementProjectInfoFluent<A>{

    private String id;
    private String key;
    private String name;

    public V1alpha1ProjectManagementProjectInfoFluentImpl(){
    }
    public V1alpha1ProjectManagementProjectInfoFluentImpl(V1alpha1ProjectManagementProjectInfo instance){
            this.withId(instance.getId());

            this.withKey(instance.getKey());

            this.withName(instance.getName());

    }

    public String getId(){
            return this.id;
    }

    public A withId(String id){
            this.id=id; return (A) this;
    }

    public Boolean hasId(){
            return this.id != null;
    }

    public A withNewId(String arg1){
            return (A)withId(new String(arg1));
    }

    public A withNewId(StringBuilder arg1){
            return (A)withId(new String(arg1));
    }

    public A withNewId(StringBuffer arg1){
            return (A)withId(new String(arg1));
    }

    public String getKey(){
            return this.key;
    }

    public A withKey(String key){
            this.key=key; return (A) this;
    }

    public Boolean hasKey(){
            return this.key != null;
    }

    public A withNewKey(String arg1){
            return (A)withKey(new String(arg1));
    }

    public A withNewKey(StringBuilder arg1){
            return (A)withKey(new String(arg1));
    }

    public A withNewKey(StringBuffer arg1){
            return (A)withKey(new String(arg1));
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1ProjectManagementProjectInfoFluentImpl that = (V1alpha1ProjectManagementProjectInfoFluentImpl) o;
            if (id != null ? !id.equals(that.id) :that.id != null) return false;
            if (key != null ? !key.equals(that.key) :that.key != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            return true;
    }




}
